@@ -29,7 +29,6 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.BitSet;
 import java.util.List;
-import java.util.WeakHashMap;
 
 /**
  * Class for reading BAM file indices, caching each contig as it's loaded and
@@ -37,8 +36,13 @@ import java.util.WeakHashMap;
  */
 class CachingBAMFileIndex extends AbstractBAMFileIndex implements BrowseableBAMIndex
 {
-    private Integer mLastReferenceRetrieved = null;
-    private final WeakHashMap<Integer,BAMIndexContent> mQueriesByReference = new WeakHashMap<Integer,BAMIndexContent>();
+    // Since null is a valid return value for this index, it's possible to have lastReferenceIndex != null and
+    // lastReference == null, this is effectively caching the return value null
+    private Integer lastReferenceIndex = null;
+    private BAMIndexContent lastReference = null;
+
+    private long cacheHits = 0;
+    private long cacheMisses = 0;
 
     public CachingBAMFileIndex(final File file, final SAMSequenceDictionary dictionary) {
         super(file, dictionary);
@@ -110,7 +114,7 @@ class CachingBAMFileIndex extends AbstractBAMFileIndex implements BrowseableBAMI
         final int firstLocusInBin = getFirstLocusInBin(bin);
 
         // Add the specified bin to the tree if it exists.
-        final List<Bin> binTree = new ArrayList<Bin>();
+        final List<Bin> binTree = new ArrayList<>();
         if(indexQuery.containsBin(bin))
             binTree.add(indexQuery.getBins().getBin(bin.getBinNumber()));
 
@@ -139,35 +143,31 @@ class CachingBAMFileIndex extends AbstractBAMFileIndex implements BrowseableBAMI
      * Looks up the cached BAM query results if they're still in the cache and not expired.  Otherwise,
      * retrieves the cache results from disk.
      * @param referenceIndex The reference to load.  CachingBAMFileIndex only stores index data for entire references. 
-     * @return The index information for this reference.
+     * @return The index information for this reference or null if no index information is available for the given index.
      */
     @Override
     protected BAMIndexContent getQueryResults(final int referenceIndex) {
-        // WeakHashMap is a bit weird in that its lookups are done via equals() equality, but expirations must be
-        // handled via == equality.  This implementation jumps through a few hoops to make sure that == equality still
-        // holds even in the context of boxing/unboxing.
 
         // If this query is for the same reference index as the last query, return it.
-        if(mLastReferenceRetrieved!=null && mLastReferenceRetrieved == referenceIndex)
-            return mQueriesByReference.get(referenceIndex);
-
-        // If not, check to see whether it's available in the cache.
-        BAMIndexContent queryResults = mQueriesByReference.get(referenceIndex);
-        if(queryResults != null) {
-            mLastReferenceRetrieved = referenceIndex;
-            mQueriesByReference.put(referenceIndex,queryResults);
-            return queryResults;
+        // This compares a boxed Integer to an int with == which is ok because the Integer will be unboxed to the primitive value
+        if(lastReferenceIndex!=null && lastReferenceIndex == referenceIndex){
+            cacheHits++;
+            return lastReference;
         }
 
-        // If not in the cache, attempt to load it from disk.
-        queryResults = query(referenceIndex,1,-1);
-        if(queryResults != null) {
-            mLastReferenceRetrieved = referenceIndex;
-            mQueriesByReference.put(referenceIndex,queryResults);
-            return queryResults;
-        }
+        // If not attempt to load it from disk.
+        final BAMIndexContent queryResults = query(referenceIndex,1,-1);
+        cacheMisses++;
+        lastReferenceIndex = referenceIndex;
+        lastReference = queryResults;
+        return lastReference;
+    }
 
-        // Not even available on disk.
-        return null;
+    public long getCacheHits() {
+        return cacheHits;
+    }
+
+    public long getCacheMisses() {
+        return cacheMisses;
     }
 }
