@@ -1,5 +1,6 @@
 package htsjdk.samtools;
 
+import htsjdk.samtools.seekablestream.SeekableStream;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.RuntimeIOException;
 
@@ -18,4 +19,13 @@ class IndexFileBufferFactory {
 
         return isCompressed ? new CompressedIndexFileBuffer(file) : (enableMemoryMapping ? new MemoryMappedFileBuffer(file) : new RandomAccessFileBuffer(file));
     }
+
+    static IndexFileBuffer getBuffer(SeekableStream seekableStream) {
+        boolean isCompressed;
+        isCompressed = IOUtil.isGZIPInputStream(seekableStream);
+
+        return isCompressed ?
+                new CompressedIndexFileBuffer(seekableStream) :
+                new IndexStreamBuffer(seekableStream);
+    }
 }
