@@ -25,7 +25,6 @@ package htsjdk.samtools;
 
 import htsjdk.samtools.util.CloseableIterator;
 
-import java.io.Serializable;
 import java.util.Collection;
 import java.util.Map;
 import java.util.PriorityQueue;
@@ -209,9 +208,7 @@ public class MergingSamRecordIterator implements CloseableIterator<SAMRecord> {
      * sequence dictionary.  I hate the fact that this extends SAMRecordCoordinateComparator, but it avoids
      * more copy & paste.
      */
-    private class MergedSequenceDictionaryCoordinateOrderComparator extends SAMRecordCoordinateComparator implements Serializable {
-        private static final long serialVersionUID = 1L;
-
+    private class MergedSequenceDictionaryCoordinateOrderComparator extends SAMRecordCoordinateComparator {
         @Override
         public int fileOrderCompare(final SAMRecord samRecord1, final SAMRecord samRecord2) {
             final int referenceIndex1 = getReferenceIndex(samRecord1);
