@@ -34,12 +34,19 @@ import htsjdk.samtools.SAMSequenceRecord;
  * exception.
  */
 public class CRAMLazyReferenceSource implements CRAMReferenceSource {
+    private static final String NO_REF_MESSAGE = "A reference must be supplied that includes the reference sequence for %s.";
 
     @Override
     public byte[] getReferenceBases(final SAMSequenceRecord sequenceRecord, final boolean tryNameVariants) {
-        throw new IllegalArgumentException(
-                String.format("A reference must be supplied that includes the reference sequence for %s.",
-                        sequenceRecord.getSequenceName()));
+        throw new IllegalArgumentException(String.format(NO_REF_MESSAGE, sequenceRecord.getSequenceName()));
+    }
+
+    @Override
+    public byte[] getReferenceBasesByRegion(
+            final SAMSequenceRecord sequenceRecord,
+            final int zeroBasedStart,
+            final int requestedRegionLength) {
+        throw new IllegalArgumentException(String.format(NO_REF_MESSAGE, sequenceRecord.getSequenceName()));
     }
 
 }
