@@ -31,14 +31,17 @@ import htsjdk.variant.utils.GeneralUtils;
 import htsjdk.variant.vcf.VCFConstants;
 import htsjdk.variant.vcf.VCFUtils;
 
+import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.Deque;
 import java.util.EnumMap;
 import java.util.List;
 import java.util.Map;
 import java.util.HashMap;
 
-public class GenotypeLikelihoods {
+public final class GenotypeLikelihoods {
     // caches likelihoods
     private final static GenotypeNumLikelihoodsCache numLikelihoodCache = new GenotypeNumLikelihoodsCache();
 
@@ -67,7 +70,8 @@ public class GenotypeLikelihoods {
      * For example, for a ploidy of 3, the allele lists for each PL index is:
      * {0,0,0}, {0,0,1}, {0,1,1}, {1,1,1}, {0,0,2}, {0,1,2}, {1,1,2}, {0,2,2}, {1,2,2}, {2,2,2}
      */
-    protected final static Map<Integer, List<List<Integer>>> anyploidPloidyToPLIndexToAlleleIndices = new HashMap<Integer, List<List<Integer>>>();
+    private final static Map<Integer, PLIndexAllelesList> anyploidPloidyToPLIndexAllelesList = new HashMap<>();
+
 
     public final static GenotypeLikelihoods fromPLField(String PLs) {
         return new GenotypeLikelihoods(PLs);
@@ -361,60 +365,6 @@ public class GenotypeLikelihoods {
         return cache;
     }
 
-
-    /**
-     * Calculate the alleles for each PL index for a ploidy.
-     * Creates the ordering for all possible combinations of ploidy alleles. Computed recursively and the
-     * result is stored in a cache.
-     *
-     * The implementation is described in The Variant Call Format Specification VCF 4.3, Section 1.6.2 Genotype fields
-     * The likelihoods are ordered for ploidy P and N alternate alleles as follows:
-     * for aP = 0...N
-     *  for aP-1 = 0...aP
-     *      ...
-     *      for a1 = 0...a2
-     *          a1,a2..aP
-     *
-     * This is implemented recursively:
-     *
-     * PLIndexToAlleleIndices(N, P, suffix=empty):
-     *      for a in 0...N
-     *          if (P == 1) accum += (a + suffix)  // have all the alleles for a PL index
-     *          if (P > 1) PLIndexToAlleleIndices(a, P-1, a + suffix )
-     *
-     * @param altAlleles     Number of alternate alleles
-     * @param ploidy         Number of chromosomes in set
-     * @param anyploidPLIndexToAlleleIndices PL index to the alleles of general ploidy over all possible alternate alleles
-     * @param genotype       An entry of ploidy alleles
-     */
-    private static void calculatePLIndexToAlleleIndices(final int altAlleles, final int ploidy, final List<List<Integer>> anyploidPLIndexToAlleleIndices,
-                                                   final List<Integer> genotype) {
-        for (int a=0; a <= altAlleles; a++) {
-            final List<Integer> gt = new ArrayList<Integer>(Arrays.asList(a));
-            gt.addAll(genotype);
-            if ( ploidy == 1 ) {// have all ploidy alleles for a PL index
-                anyploidPLIndexToAlleleIndices.add(gt);
-            } else if ( ploidy > 1 ) {
-                calculatePLIndexToAlleleIndices(a, ploidy - 1, anyploidPLIndexToAlleleIndices, gt);
-            }
-        }
-    }
-
-    /**
-     * Calculate the cache of allele indices for each PL index for a ploidy.
-     * Calculation in @see #calculatePLIndexToAlleleIndices
-     *
-     * @param altAlleles Number of alternate alleles
-     * @param ploidy    Number of chromosomes in set
-     * @return PL index to the alleles of general ploidy over all possible alternate alleles
-     * @return The alleles for each PL index for a ploidy
-     */
-    protected static List<List<Integer>> calculateAnyploidPLcache(final int altAlleles, final int ploidy) {
-        List<List<Integer>> anyploidPLIndexToAlleleIndices = new ArrayList<List<Integer>>();
-        calculatePLIndexToAlleleIndices(altAlleles, ploidy, anyploidPLIndexToAlleleIndices, new ArrayList<Integer>());
-        return anyploidPLIndexToAlleleIndices;
-    }
-
     // -------------------------------------------------------------------------------------
     //
     // num likelihoods given number of alleles and ploidy
@@ -489,48 +439,108 @@ public class GenotypeLikelihoods {
     }
 
     /**
-     * Initialize cache of allele anyploid indices
-     * If initialized multiple times with the same ploidy, the alternate alleles from the last initialization will be used
-     *
-     * @param altAlleles number of alternate alleles
-     * @param ploidy    number of chromosomes
+     * This method is no longer necessary and is now a no-op
      * @throws IllegalArgumentException if altAlleles or ploidy &lt= 0
+     * @deprecated as of sept 2020, this method is no longer necessary
      */
+    @Deprecated
     public static synchronized void initializeAnyploidPLIndexToAlleleIndices(final int altAlleles, final int ploidy) {
-        if ( altAlleles <= 0 )
-            throw new IllegalArgumentException("Must have at least one alternate allele, not " + altAlleles );
-
-        if ( ploidy <= 0 )
-            throw new IllegalArgumentException("Ploidy must be at least 1, not " + ploidy);
-
-        // create the allele indices for each PL index for a ploidy
-        anyploidPloidyToPLIndexToAlleleIndices.put(ploidy, calculateAnyploidPLcache(altAlleles, ploidy));
     }
 
     /**
      * Get the allele ploidy indices for the given PL index
-     * Must use the same ploidy as @see #initializeAnyploidPLIndexToAlleleIndices
      *
      * @param PLindex   the PL index
      * @param ploidy    number of chromosomes
      * @return the ploidy allele indices
-     * @throws IllegalStateException if @see #anyploidPloidyToPLIndexToAlleleIndices does not contain the requested ploidy or PL index
+     * @throws IllegalStateException if PLindex < 0 or ploidy < 0
      */
     public static synchronized List<Integer> getAlleles(final int PLindex, final int ploidy) {
+        if ( PLindex < 0) {
+            throw new IllegalStateException("The PL index " + PLindex + " cannot be negative");
+        }
+
+        if (ploidy <= 0) {
+            throw new IllegalStateException("The ploidy " + ploidy +" must be greater than zero");
+        }
+
         if ( ploidy == 2 ) { // diploid
             final GenotypeLikelihoodsAllelePair pair = getAllelePair(PLindex);
             return Arrays.asList(pair.alleleIndex1, pair.alleleIndex2);
         } else { // non-diploid
-            if (!anyploidPloidyToPLIndexToAlleleIndices.containsKey(ploidy))
-                throw new IllegalStateException("Must initialize the cache of allele anyploid indices for ploidy " + ploidy);
+            final PLIndexAllelesList plIndexAllelesList = anyploidPloidyToPLIndexAllelesList.computeIfAbsent(ploidy, k -> new PLIndexAllelesList(ploidy));
+            return plIndexAllelesList.getAlleles(PLindex);
+        }
+    }
 
-            if (PLindex < 0 || PLindex >= anyploidPloidyToPLIndexToAlleleIndices.get(ploidy).size()) {
-                final String msg = "The PL index " + PLindex + " does not exist for " + ploidy + " ploidy, " +
-                        (PLindex < 0 ? "cannot have a negative value." : "initialized the cache of allele anyploid indices with the incorrect number of alternate alleles.");
-                throw new IllegalStateException(msg);
+    private static class PLIndexAllelesList {
+        final List<List<Integer>> allelesList = new ArrayList<>();
+        int alleleToIncrementForNextIndex;
+        final Deque<Integer> availableAllelesToIncrementDeque = new ArrayDeque<>();
+        int ploidy;
+
+        PLIndexAllelesList(final int ploidy) {
+            this.ploidy = ploidy;
+            this.alleleToIncrementForNextIndex = ploidy - 1;
+            this.allelesList.add(new ArrayList<>(Collections.nCopies(ploidy, 0)));
+        }
+
+        /**
+         * Calculate the alleles for the given PL index for a ploidy.
+         * Creates the ordering for all PL indices less than or equal to PLIndex, and stores them for future use.
+         *
+         * The implementation is described in The Variant Call Format Specification VCF 4.3, Section 1.6.2 Genotype fields
+         * The likelihoods are ordered for ploidy P and N alternate alleles as follows:
+         * for aP = 0...N
+         *  for aP-1 = 0...aP
+         *      ...
+         *      for a1 = 0...a2
+         *          a1,a2..aP
+         *
+         * However, instead of having a set number of alternate alleles, we allow the outer loop to continue indefinitely, and break out
+         * once the correct PLIndex has been reached.  The state of the looping is stored, so that calculating higher indices can start
+         * from where we left off, instead of going back the the beginning.
+         *
+         * To do this, we do not keep track of the indices of each of the P loops explicitly.  In the loop pseudocode, we note that writing a new allele list
+         * corresponds to incrementing one loop, leaving the indices in the loops above it unchanged, and resetting the indices in the loops below it to zero.
+         * After incrementing the index of a particular loop, we next increment the index of the loop just below it, unless we have just incremented the lowest loop,
+         * in which case we next incremented whichever is the lowest loop that can still be incremented.  Thus, we note that we can write the list of alleles for the
+         * PLIndex pl_i based on the PLIndex pl_i - 1 if we know which single allele must be incremented. If we know we incremented allele a_i to
+         * create the list of alleles for pl_i - 1 from the list of alleles for pl_i - 2, then, if the index a_i is not 0 (ie. the leftmost allele),
+         * we simply increment allele a_i - 1 to create the list of alleles for pl_i, and leave the other alleles unchanged (by construction, only alleles to
+         * the right of allele a_i - 1 will be nonzero).  If allele a_i - 1 is less than allele a_i, then we know that it can further be incremented before
+         * allele a_i, so we add the index a_i to a deque D_a (by construction, D_a will always be sorted in descending order).  If the index a_i is 0, then we poll from the end of D_a to find the next allele to increment
+         * (or set the next allele to ploidy - 1, ie the rightmost allele,  if D_a is empty).  In this case, all alleles to the left of the incremented allele
+         * are reset to 0, and all alleles to the right are left unchanged.
+         *
+         * The algorithm is initialized in thr constructor for PLIndex 0 with a list of P 0's and by setting the next allele to increment as ploidy - 1 (ie, the rightmost allele).
+         * @param PLIndex
+         * @return
+         */
+
+        private List<Integer> getAlleles(final int PLIndex) {
+
+            while(PLIndex >= allelesList.size()) {
+                final List<Integer> nextPLs;
+                final int alleleToIncrement;
+                if (alleleToIncrementForNextIndex < 0) {
+                    alleleToIncrement = availableAllelesToIncrementDeque.isEmpty() ? ploidy - 1 : availableAllelesToIncrementDeque.removeLast();
+
+                    nextPLs = new ArrayList<>(Collections.nCopies(alleleToIncrement, 0));
+                    nextPLs.addAll(allelesList.get(allelesList.size() - 1).subList(alleleToIncrement, ploidy));
+                } else {
+                    alleleToIncrement = alleleToIncrementForNextIndex;
+                    nextPLs = new ArrayList<>(allelesList.get(allelesList.size() - 1));
+                }
+                final int incrementedValue = nextPLs.get(alleleToIncrement) + 1;
+                nextPLs.set(alleleToIncrement, incrementedValue);
+                alleleToIncrementForNextIndex = alleleToIncrement - 1;
+                if (alleleToIncrement < ploidy - 1 && nextPLs.get(alleleToIncrement) < nextPLs.get(alleleToIncrement + 1)) {
+                    availableAllelesToIncrementDeque.add(alleleToIncrement);
+                }
+                allelesList.add(nextPLs);
             }
-
-            return anyploidPloidyToPLIndexToAlleleIndices.get(ploidy).get(PLindex);
+            return allelesList.get(PLIndex);
         }
     }
 
