@@ -33,43 +33,32 @@ import htsjdk.tribble.NameAwareCodec;
 import htsjdk.tribble.TribbleException;
 import htsjdk.tribble.index.tabix.TabixFormat;
 import htsjdk.tribble.util.ParsingUtils;
+import htsjdk.utils.ValidationUtils;
 import htsjdk.variant.utils.GeneralUtils;
-import htsjdk.variant.variantcontext.Allele;
-import htsjdk.variant.variantcontext.Genotype;
-import htsjdk.variant.variantcontext.GenotypeBuilder;
-import htsjdk.variant.variantcontext.GenotypeLikelihoods;
-import htsjdk.variant.variantcontext.LazyGenotypesContext;
-import htsjdk.variant.variantcontext.VariantContext;
-import htsjdk.variant.variantcontext.VariantContextBuilder;
+import htsjdk.variant.variantcontext.*;
 
-import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.LinkedHashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.StringTokenizer;
+import java.util.*;
 import java.util.zip.GZIPInputStream;
 
-
 public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext> implements NameAwareCodec {
     public final static int MAX_ALLELE_SIZE_BEFORE_WARNING = (int)Math.pow(2, 20);
 
-    protected final static int NUM_STANDARD_FIELDS = 8;  // INFO is the 8th column
+    protected final static int NUM_STANDARD_FIELDS = 8;  // INFO is the 8th
 
     // we have to store the list of strings that make up the header until they're needed
     protected VCFHeader header = null;
     protected VCFHeaderVersion version = null;
 
+    private final static VCFTextTransformer percentEncodingTextTransformer = new VCFPercentEncodedTextTransformer();
+    private final static VCFTextTransformer passThruTextTransformer = new VCFPassThruTextTransformer();
+    //by default, we use the passThruTextTransformer (assume pre v4.3)
+    private VCFTextTransformer vcfTextTransformer = passThruTextTransformer;
+
     // a mapping of the allele
     protected Map<String, List<Allele>> alleleMap = new HashMap<String, List<Allele>>(3);
     
@@ -212,8 +201,14 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
                     final VCFContigHeaderLine contig = new VCFContigHeaderLine(str.substring(9), version, VCFConstants.CONTIG_HEADER_START.substring(2), contigCounter++);
                     metaData.add(contig);
                 } else if ( str.startsWith(VCFConstants.ALT_HEADER_START) ) {
-                    final VCFSimpleHeaderLine alt = new VCFSimpleHeaderLine(str.substring(6), version, VCFConstants.ALT_HEADER_START.substring(2), Arrays.asList("ID", "Description"));
-                    metaData.add(alt);
+                    metaData.add(getAltHeaderLine(str.substring(VCFConstants.ALT_HEADER_OFFSET), version));
+                } else if ( str.startsWith(VCFConstants.PEDIGREE_HEADER_START) && version.isAtLeastAsRecentAs(VCFHeaderVersion.VCF4_3)) {
+                    // only model pedigree header lines as structured header lines starting with v4.3
+                    metaData.add(getPedigreeHeaderLine(str.substring(VCFConstants.PEDIGREE_HEADER_OFFSET), version));
+                } else if ( str.startsWith(VCFConstants.META_HEADER_START) ) {
+                    metaData.add(getMetaHeaderLine(str.substring(VCFConstants.META_HEADER_OFFSET), version));
+                } else if ( str.startsWith(VCFConstants.SAMPLE_HEADER_START) ) {
+                    metaData.add(getSampleHeaderLine(str.substring(VCFConstants.SAMPLE_HEADER_OFFSET), version));
                 } else {
                     int equals = str.indexOf('=');
                     if ( equals != -1 )
@@ -222,9 +217,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
             }
         }
 
-        this.header = new VCFHeader(metaData, sampleNames);
-        if ( doOnTheFlyModifications )
-            this.header = VCFStandardHeaderLines.repairStandardHeaderLines(this.header);
+        setVCFHeader(new VCFHeader(version, metaData, sampleNames), version);
         return this.header;
     }
 
@@ -244,19 +237,77 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
     }
 
     /**
-	 * Explicitly set the VCFHeader on this codec. This will overwrite the header read from the file
-	 * and the version state stored in this instance; conversely, reading the header from a file will
-	 * overwrite whatever is set here. The returned header may not be identical to the header argument
-	 * since the header lines may be "repaired" (i.e., rewritten) if doOnTheFlyModifications is set.
-	 */
-	public VCFHeader setVCFHeader(final VCFHeader header, final VCFHeaderVersion version) {
-		this.version = version;
+     * Explicitly set the VCFHeader on this codec. This will overwrite the header read from the file
+     * and the version state stored in this instance; conversely, reading the header from a file will
+     * overwrite whatever is set here.
+     *
+     * @param newHeader
+     * @param newVersion
+     * @return the actual header for this codec. The returned header may not be identical to the header
+     * argument since the header lines may be "repaired" (i.e., rewritten) if doOnTheFlyModifications is set.
+     * @throws TribbleException if the requested header version is not compatible with the existing version
+     */
+    public VCFHeader setVCFHeader(final VCFHeader newHeader, final VCFHeaderVersion newVersion) {
+        validateHeaderVersionTransition(newHeader, newVersion);
+        if (this.doOnTheFlyModifications) {
+            final VCFHeader repairedHeader = VCFStandardHeaderLines.repairStandardHeaderLines(newHeader);
+            // validate the new header after repair to ensure the resulting header version is
+            // still compatible with the current version
+            validateHeaderVersionTransition(repairedHeader, newVersion);
+            this.header = repairedHeader;
+        } else {
+            this.header = newHeader;
+        }
 
-		if (this.doOnTheFlyModifications) this.header = VCFStandardHeaderLines.repairStandardHeaderLines(header);
-		else this.header = header;
+        this.version = newVersion;
+        this.vcfTextTransformer = getTextTransformerForVCFVersion(newVersion);
 
-		return this.header;
-	}
+        return this.header;
+    }
+
+    /**
+     * Create and return a VCFAltHeaderLine object from a header line string that conforms to the {@code sourceVersion}
+     * @param headerLineString VCF header line being parsed without the leading "##ALT="
+     * @param sourceVersion the VCF header version derived from which the source was retrieved. The resulting header
+     *                      line object should be validate for this header version.
+     * @return a VCFAltHeaderLine object
+     */
+    public VCFAltHeaderLine getAltHeaderLine(final String headerLineString, final VCFHeaderVersion sourceVersion) {
+        return new VCFAltHeaderLine(headerLineString, sourceVersion);
+    }
+
+    /**
+     * Create and return a VCFPedigreeHeaderLine object from a header line string that conforms to the {@code sourceVersion}
+     * @param headerLineString VCF header line being parsed without the leading "##PEDIGREE="
+     * @param sourceVersion the VCF header version derived from which the source was retrieved. The resulting header
+     *                      line object should be validate for this header version.
+     * @return a VCFPedigreeHeaderLine object
+     */
+    public VCFPedigreeHeaderLine getPedigreeHeaderLine(final String headerLineString, final VCFHeaderVersion sourceVersion) {
+        return new VCFPedigreeHeaderLine(headerLineString, sourceVersion);
+    }
+
+    /**
+     * Create and return a VCFMetaHeaderLine object from a header line string that conforms to the {@code sourceVersion}
+     * @param headerLineString VCF header line being parsed without the leading "##META="
+     * @param sourceVersion the VCF header version derived from which the source was retrieved. The resulting header
+     *                      line object should be validate for this header version.
+     * @return a VCFMetaHeaderLine object
+     */
+    public VCFMetaHeaderLine getMetaHeaderLine(final String headerLineString, final VCFHeaderVersion sourceVersion) {
+        return new VCFMetaHeaderLine(headerLineString, sourceVersion);
+    }
+
+    /**
+     * Create and return a VCFSampleHeaderLine object from a header line string that conforms to the {@code sourceVersion}
+     * @param headerLineString VCF header line being parsed without the leading "##SAMPLE="
+     * @param sourceVersion the VCF header version derived from which the source was retrieved. The resulting header
+     *                      line object should be validate for this header version.
+     * @return a VCFSampleHeaderLine object
+     */
+    public VCFSampleHeaderLine getSampleHeaderLine(final String headerLineString, final VCFHeaderVersion sourceVersion) {
+        return new VCFSampleHeaderLine(headerLineString, sourceVersion);
+    }
 
     /**
      * the fast decode function
@@ -277,6 +328,40 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         return decodeLine(line, true);
     }
 
+    /**
+     * Throw if new a version/header are not compatible with the existing version/header. Generally, any version
+     * before v4.2 can be up-converted to v4.2, but not to v4.3. Once a header is established as v4.3, it cannot
+     * can not be up or down converted, and it must remain at v4.3.
+     * @param newHeader
+     * @param newVersion
+     * @throws TribbleException if the header conversion is not valid
+     */
+    private void validateHeaderVersionTransition(final VCFHeader newHeader, final VCFHeaderVersion newVersion) {
+        ValidationUtils.nonNull(newHeader);
+        ValidationUtils.nonNull(newVersion);
+
+        VCFHeader.validateVersionTransition(version, newVersion);
+
+        // If this codec currently has no header (this happens when the header is being established for
+        // the first time during file parsing), establish an initial header and version, and bypass
+        // validation.
+        if (header != null && newHeader.getVCFHeaderVersion() != null) {
+            VCFHeader.validateVersionTransition(header.getVCFHeaderVersion(), newHeader.getVCFHeaderVersion());
+        }
+    }
+
+    /**
+     * For v4.3 up, attribute values can contain embedded percent-encoded characters which must be decoded
+     * on read. Return a version-aware text transformer that can decode encoded text.
+     * @param targetVersion the version for which a transformer is bing requested
+     * @return a {@link VCFTextTransformer} suitable for the targetVersion
+     */
+    private VCFTextTransformer getTextTransformerForVCFVersion(final VCFHeaderVersion targetVersion) {
+        return targetVersion != null && targetVersion.isAtLeastAsRecentAs(VCFHeaderVersion.VCF4_3) ?
+                percentEncodingTextTransformer :
+                passThruTextTransformer;
+    }
+
     private VariantContext decodeLine(final String line, final boolean includeGenotypes) {
         // the same line reader is not used for parsing the header and parsing lines, if we see a #, we've seen a header line
         if (line.startsWith(VCFHeader.HEADER_INDICATOR)) return null;
@@ -319,7 +404,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         builder.chr(chr);
         int pos = -1;
         try {
-            pos = Integer.valueOf(parts[1]);
+            pos = Integer.parseInt(parts[1]);
         } catch (NumberFormatException e) {
             generateException(parts[1] + " is not a valid start position in the VCF format");
         }
@@ -332,19 +417,21 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         else
             builder.id(parts[2]);
 
-        final String ref = getCachedString(parts[3].toUpperCase());
-        final String alts = getCachedString(parts[4]);
+        final String ref = parts[3].toUpperCase();
+        final String alts = parts[4];
         builder.log10PError(parseQual(parts[5]));
 
         final List<String> filters = parseFilters(getCachedString(parts[6]));
-        if ( filters != null ) builder.filters(new HashSet<String>(filters));
+        if ( filters != null ) {
+            builder.filters(new HashSet<>(filters));
+        }
         final Map<String, Object> attrs = parseInfo(parts[7]);
         builder.attributes(attrs);
 
         if ( attrs.containsKey(VCFConstants.END_KEY) ) {
             // update stop with the end key if provided
             try {
-                builder.stop(Integer.valueOf(attrs.get(VCFConstants.END_KEY).toString()));
+                builder.stop(Integer.parseInt(attrs.get(VCFConstants.END_KEY).toString()));
             } catch (Exception e) {
                 generateException("the END value in the INFO field is not valid");
             }
@@ -440,14 +527,14 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
                     // split on the INFO field separator
                     List<String> infoValueSplit = ParsingUtils.split(valueString, VCFConstants.INFO_FIELD_ARRAY_SEPARATOR_CHAR);
                     if ( infoValueSplit.size() == 1 ) {
-                        value = infoValueSplit.get(0);
+                        value = vcfTextTransformer.decodeText(infoValueSplit.get(0));
                         final VCFInfoHeaderLine headerLine = header.getInfoHeaderLine(key);
                         if ( headerLine != null && headerLine.getType() == VCFHeaderLineType.Flag && value.equals("0") ) {
                             // deal with the case where a flag field has =0, such as DB=0, by skipping the add
                             continue;
                         }
                     } else {
-                        value = infoValueSplit;
+                        value = vcfTextTransformer.decodeText(infoValueSplit);
                     }
                 } else {
                     key = infoFields.get(i);
@@ -486,7 +573,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
             return Allele.NO_CALL;
         final int i;
         try {
-            i = Integer.valueOf(index);
+            i = Integer.parseInt(index);
         } catch ( NumberFormatException e ) {
             throw new TribbleException.InternalCodecException("The following invalid GT allele index was encountered in the file: " + index);
         }
@@ -530,7 +617,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         if ( qualString.equals(VCFConstants.MISSING_VALUE_v4))
             return VariantContext.NO_LOG10_PERROR;
 
-        Double val = Double.valueOf(qualString);
+        Double val = VCFUtils.parseVcfDouble(qualString);
 
         // check to see if they encoded the missing qual score in VCF 3 style, with either the -1 or -1.0.  check for val < 0 to save some CPU cycles
         if ((val < 0) && (Math.abs(val - VCFConstants.MISSING_QUALITY_v3_DOUBLE) < VCFConstants.VCF_ENCODING_EPSILON))
@@ -577,7 +664,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
             System.err.println(String.format("Allele detected with length %d exceeding max size %d at approximately line %d, likely resulting in degraded VCF processing performance", allele.length(), MAX_ALLELE_SIZE_BEFORE_WARNING, lineNo));
         }
 
-        if ( isSymbolicAllele(allele) ) {
+        if (Allele.wouldBeSymbolicAllele(allele.getBytes())) {
             if ( isRef ) {
                 generateException("Symbolic alleles not allowed as reference allele: " + allele, lineNo);
             }
@@ -609,18 +696,6 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         return "unparsable vcf record with allele " + allele;
     }
 
-    /**
-     * return true if this is a symbolic allele (e.g. <SOMETAG>) or
-     * structural variation breakend (with [ or ]), otherwise false
-     * @param allele the allele to check
-     * @return true if the allele is a symbolic allele, otherwise false
-     */
-    private static boolean isSymbolicAllele(String allele) {
-        return (allele != null && allele.length() > 2 &&
-                ((allele.startsWith("<") && allele.endsWith(">")) ||
-                        (allele.contains("[") || allele.contains("]"))));
-    }
-
     /**
      * parse a single allele, given the allele list
      * @param alleles the alleles available
@@ -698,6 +773,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
         boolean PlIsSet = false;
         for (int genotypeOffset = 1; genotypeOffset < nParts; genotypeOffset++) {
             List<String> genotypeValues = ParsingUtils.split(genotypeParts[genotypeOffset], VCFConstants.GENOTYPE_FIELD_SEPARATOR_CHAR);
+            genotypeValues = vcfTextTransformer.decodeText(genotypeValues);
 
             final String sampleName = sampleNameIterator.next();
             final GenotypeBuilder gb = new GenotypeBuilder(sampleName);
@@ -729,7 +805,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
                             if ( genotypeValues.get(i).equals(VCFConstants.MISSING_GENOTYPE_QUALITY_v3) )
                                 gb.noGQ();
                             else
-                                gb.GQ((int)Math.round(Double.valueOf(genotypeValues.get(i))));
+                                gb.GQ((int)Math.round(VCFUtils.parseVcfDouble(genotypeValues.get(i))));
                         } else if (gtKey.equals(VCFConstants.GENOTYPE_ALLELE_DEPTHS)) {
                             gb.AD(decodeInts(genotypeValues.get(i)));
                         } else if (gtKey.equals(VCFConstants.GENOTYPE_PL_KEY)) {
@@ -741,7 +817,7 @@ public abstract class AbstractVCFCodec extends AsciiFeatureCodec<VariantContext>
                                 gb.PL(GenotypeLikelihoods.fromGLField(genotypeValues.get(i)).getAsPLs());
                             }
                         } else if (gtKey.equals(VCFConstants.DEPTH_KEY)) {
-                            gb.DP(Integer.valueOf(genotypeValues.get(i)));
+                            gb.DP(Integer.parseInt(genotypeValues.get(i)));
                         } else {
                             gb.attribute(gtKey, genotypeValues.get(i));
                         }
