@@ -37,7 +37,7 @@ import java.util.List;
  * Date: 2012-Dec-13
  */
 public class TestUtils {
-    public static String DATA_DIR = "src/test/resources/htsjdk/tribble/";
+    public static final String DATA_DIR = "src/test/resources/htsjdk/tribble/";
 
     /**
      * A utility method for copying a tribble file (and possibly its index) into a Jimfs-like FileSystem
@@ -51,7 +51,7 @@ public class TestUtils {
      * @throws URISyntaxException if the provided strings cannot be understoos as Uris.
      */
 
-    public static Path getTribbleFileInJimfs(String vcf, String index, FileSystem fileSystem) throws IOException, URISyntaxException {
+    public static Path getTribbleFileInJimfs(String vcf, String index, FileSystem fileSystem) throws IOException {
         final FileSystem fs = fileSystem;
         final Path root = fs.getPath("/");
         final Path vcfPath = Paths.get(vcf);
